@@ -1,5 +1,6 @@
-use indicatif::ProgressBar;
 use std::time::Duration;
+
+use indicatif::ProgressBar;
 use tokio::runtime;
 use tokio::time::interval;
 
@@ -9,7 +10,7 @@ fn main() {
     let pb = ProgressBar::new(steps);
 
     // Stream of events, triggering every 5ms.
-    let mut rt = runtime::Builder::new()
+    let rt = runtime::Builder::new_current_thread()
         .enable_time()
         .build()
         .expect("failed to create runtime");
